function ODMcusp(s, a, b, N, x1, x2, nb, np)
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ODMcusp(s, a, b, N, x1, x2, nb, np)
% ____________________________________________________________________________
% 18.385 (Nonlinear Dynamical Systems).    MIT, Fall 1999-2004. R. R. Rosales.
%
% Script to plot iterations of the map y = L*(1 - (abs(1-2*x))^s), where s > 0.
%
% The script takes N values of L ---- equi-distributed in the interval [a, b],
% where 0 <= a < b <= 1. Then the map is iterated nb times --- starting from a
% random x in [x1, x2], where 0 <= x1 < x2 <=1.  Then the next np iterates are
% plotted in the [x, L] plane (in the selected range: x in [x1, x2]).
%
% The first nb iterates let the map settle into the attracting set (nb must be
% picked reasonably large).  The second set of np iterates plots the attractor
% (if the attractor is complicated, np must be large).   Thus the structure of
% the set of attracting points for the map (as a function of L) is visualized.
%
% Stability at x = 0 follows from y'(0) = 2*s*L.  Try s>0.5 to get an unstable
% range in L <= 1. Best pictures follow for s > 1.
%
% A cusp at x = 0.5 occurs for s < 1.   For s = 1 this is the tent map and for
% s = 2 this is the quadratic map --- the scripts ODNquad and ODMtent are more
% efficient in these cases.
%
% IT IS POSSIBLE TO CALL THE SCRIPT WITHOUT ANY ARGUMENTS, as in
% >> ODMcusp
% where >> is the MatLab prompt.       Then the script will request the needed
% inputs via screen prompts to the user.
%
% The script has NO OUTPUT VARIABLES.
%
% Copyright at the end of this script file.
%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

HNB = 'HelveticaNarrowBold';
FN  = 'FontName';
FS  = 'FontSize';
MS  = 'MarkerSize';
if nargin < 8
   fprintf('\n Iterates of map y = L*(1-(abs(1-2*x))^s),')
   fprintf('\n where: 0 <= L, x <= 1 and s > 0. \n')
   disp([' The iterates will be plotted for:          '; ...
         '     a <= L <= b and x1 <= x <= x2.         '; ...
         ' An equi-distributed grid in L will be used.'])
   fprintf('\n')
   s  = input('Value of s desired (CHECK help ODMcusp.) .....  s = ');
   a  = input('Lower value of the parameter L in map ........  a = ');
   b  = input('Upper value of the parameter L in map ........  b = ');
   N  = input('Step to be used in plot is dL=(b-a)/N ........  N = ');
   x1 = input('Lower value of x to be plotted ............... x1 = ');
   x2 = input('Upper value of x to be plotted ............... x2 = ');
   nb = input('Enter number of iterations before plotting ... nb = ');
   np = input('Enter number of iterations to be plotted ..... np = ');
end
nf = nb + np;
L  = a + (b-a)*(0:N)/N;
x  = x1 + (x2-x1)*rand(size(L));
for j=1:nb
   x = L.*(1 - (abs(1-2*x)).^s);
end
figure
whitebg('k')
ttt = num2str(s);
xlabel('Attractors x', FN, HNB, FS, 16)
ylabel('Parameter L',  FN, HNB, FS, 16)
title(['Cusp map:  y = L*(1 - abs(2*x-1)^s).   s = ', ttt], ...
        FN, HNB, FS, 16)
axis([x1 x2 a b])
grid on
hold on
for j=(nb+1):nf
   x = L.*(1 - (abs(1-2*x)).^s);
   plot(x,L,'.r', MS, 3)
end
hold off
zoom on
fprintf('\n Zoom is on in the figure. \n')
fprintf('\n')
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright Massachusetts Institute of Technology
% Version 01 by Rodolfo R. Rosales  10-12-1999.
% Version 02 by Rodolfo R. Rosales  09-27-2004.
% 
% Permission is hereby granted, without payment, to copy this software
% and its documentation, if any,  for non-profit academic and research
% purposes,  provided that the above copyright notice, this paragraph,
% and the following three paragraphs appear in all copies of this
% software. Use of this software constitutes acceptance of these terms
% and conditions.
%
% IN NO EVENT SHALL MIT, OR THE AUTHOR, BE LIABLE TO ANY PARTY FOR
% DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
% ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN
% IF MIT, OR THE AUTHOR, HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH
% DAMAGE.
%
% MIT, AND THE AUTHOR, SPECIFICALLY DISCLAIM ANY EXPRESS OR IMPLIED
% WARRANTIES INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
% NON-INFRINGEMENT.
%
% THIS SOFTWARE IS PROVIDED "AS IS." MIT, OR THE AUTHOR, HAVE NO
% OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS,
% OR MODIFICATIONS.
%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% EOF

