function [y, x] = ODMcusp_F(s, L, x1, x2, N, Nx)
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% [y, x] = ODMcusp_F(s, L, x1, x2, N, Nx)
% ____________________________________________________________________________
% 18.385 (Nonlinear Dynamical Systems).    MIT, Fall 1999-2004. R. R. Rosales.
%
% This script computes and plots the N-th iterate of the cusp map on a uniform
% grid (with Nx points) in  [x1, x2], where 0 <= x1 < x2 <= 1. The cusp map is
% given by:
%          y = L*(1-(abs(1-2*x))^s), where s > 0, 0 <= x <= 1 and 0 <= L <= 1.
%
% On output, y contains the values of the N-th iterate on the grid x.
%
% When N is large, it is best to have a very dense grid (Nx large); HOWEVER:
%               REMARKS ALONG THE SAME LINES AS THOSE IN 
%                 ODMtent_F APPLY FOR THE GRID DENSITY.
% NOTE that:
%
% IT IS POSSIBLE TO CALL THE SCRIPT WITHOUT ANY ARGUMENTS, as in
% >> [y, x] = ODMcusp_F;
% where >> is the MatLab prompt.       Then the script will request the needed
% inputs via screen prompts to the user.
%
% The OUTPUT VARIABLES are OPTIONAL.   Use ";" at the end of the call sequence
% to avoid screen display of the output.
%
% Copyright at the end of this script file.
%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
HNB = 'HelveticaNarrowBold';
FN  = 'FontName';
FS  = 'FontSize';
LW  = 'LineWidth';
if nargin < 6
   fprintf('\n See help ODMcusp_F for the meaning of the inputs. \n')
   L  = input('              Value of parameter L to be used .... L  = ');
   s  = input('              Value of parameter s to be used .... s  = ');
   N  = input('              Number of iterations desired ....... N  = ');
   x1 = input('              Lower extreme of interval in x ..... x1 = ');
   x2 = input('              Upper exptreme of interval in x .... x2 = ');
   Nx = input('              Number of points in x-interval ..... Nx = ');
end
figure
whitebg('k')
tt1 = num2str(N);
tt2 = num2str(L);
tt3 = num2str(s);
xlabel('Variable x', FN, HNB, FS, 16)
ylabel('N^{th} iterate of map', FN, HNB, FS, 16)
title(['N^{th} iterate of y = L*(1-(abs(1-2*x))^s).  N = ', tt1, ...
       ', L = ', tt2, ', s = ', tt3], FN, HNB, FS, 14)
axis([x1 x2 0 1])
grid on
hold on
x = x1 + (x2-x1)*(0:Nx)/Nx;
y  = x;
for n=1:N
   y = L * (1 - (abs(1-2*y)).^s); 
end
plot(x, y, '-c', LW, 2)
hold off
zoom on
fprintf('\n Zoom is on in the figure. \n')
fprintf('\n')
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright Massachusetts Institute of Technology
% Version 01 by Rodolfo R. Rosales  10-12-1999.
% Version 02 by Rodolfo R. Rosales  09-27-2004.
% 
% Permission is hereby granted, without payment, to copy this software
% and its documentation, if any,  for non-profit academic and research
% purposes,  provided that the above copyright notice, this paragraph,
% and the following three paragraphs appear in all copies of this
% software. Use of this software constitutes acceptance of these terms
% and conditions.
%
% IN NO EVENT SHALL MIT, OR THE AUTHOR, BE LIABLE TO ANY PARTY FOR
% DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
% ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN
% IF MIT, OR THE AUTHOR, HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH
% DAMAGE.
%
% MIT, AND THE AUTHOR, SPECIFICALLY DISCLAIM ANY EXPRESS OR IMPLIED
% WARRANTIES INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
% NON-INFRINGEMENT.
%
% THIS SOFTWARE IS PROVIDED "AS IS." MIT, OR THE AUTHOR, HAVE NO
% OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS,
% OR MODIFICATIONS.
%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% EOF

