function ODMusr(a, b, N, x1, x2, nb, np, f)
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ODMusr(a, b, N, x1, x2, nb, np, f)
% ____________________________________________________________________________
% 18.385 (Nonlinear Dynamical Systems).    MIT, Fall 1999-2004. R. R. Rosales.
%
% Script to plot the iterations of a user given map y = f(x, L). The following
% condition must hold:
%                   For the range a <= L <= b, the function y=f(x, L) maps an
%                   interval [A, B] into itself, where A <= x1 < x2 <= B.
%
% The script takes N values of L  --- equi-distributed in the interval [a, b].
% Then the map is iterated nb times ---  starting from a random x in [x1, x2].
% Then the next np iterates are plotted in the [x, L] plane ---  in the range:
% x1 <= x <= x2.
%
% The first nb iterates let the map settle into the attracting set (nb must be
% be picked reasonably large). The next np iterates plot the attractor (if the
% attractor is complicated, np must be large).   Thus the structure of the set
% attracting points for the map can be visualized (as a function of L).
%
% The map is entered in the form of a string variable,  involving valid MatLab
% operations.  For example: f may be 'L.*sin(x)'  or any other expression that
% involves x and L to yield an appropriate map y = f(x, L). NOTE THAT:
%
% A) The map formula must be between quotes (').
% B) The expression for f must be valid for L and x arrays of equal size, with
%    output also an array of the same size  (note that in the example above we
%    wrote 'L.*sin(x)', using the array .* multiplication operation).
%
%    B is needed because the script performs the iterations for all the values
%    of L simultaneously.
% C) IT IS POSSIBLE TO CALL THE SCRIPT WITHOUT ANY ARGUMENTS, as in
%    >> ODMusr
%    where >> is the MatLab prompt.   Input values will then be requested from
%    the user via screen prompts.
% D) There are NO OUTPUT VARIABLES.
%
% Copyright at the end of this script file.
%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

HNB = 'HelveticaNarrowBold';
FN  = 'FontName';
FS  = 'FontSize';
MS  = 'MarkerSize';
%
% --- Begin input if loop when no arguments in function call.
%
if nargin < 8
   fprintf('\n Iterates of the user given map y = f(x, L). See help.')
   fprintf('\n')
   disp(['  The iterates will be plotted for:          '; ...
         '  a <= L <= b and x1 <= x <= x2.             '; ...
         '  An equi-distributed grid in L will be used.'])
   fprintf('\n')
   a  = input('Lower value of the parameter L in map ........  a = ');
   b  = input('Upper value of the parameter L in map ........  b = ');
   N  = input('Step to be used in plot is dL=(b-a)/N ........  N = ');
   x1 = input('Lower value of x to be plotted ............... x1 = ');
   x2 = input('Upper value of x to be plotted ............... x2 = ');
   nb = input('Enter number of iterations before plotting ... nb = ');
   np = input('Enter number of iterations to be plotted ..... np = ');
   fprintf('\n')
   disp([' Now enter formula for map, between quotes, using valid'; ...
         ' MatLab operations and considering  L, x and the answer'; ...
         ' as arrays of the same size.                           ']);
   fprintf('\n')
   f  = input('Enter map. f(x, L) = ');
end
nf = nb + np;
L  = a + (b-a)*(0:N)/N;
x  = x1 + (x2-x1)*rand(size(L));
for j=1:nb
   x = eval(f);
end
figure
whitebg('k')
xlabel('Iterates x',  FN, HNB, FS, 16)
ylabel('Parameter L', FN, HNB, FS, 16)
title(['Attractors for map y = ', f, '  '], FN, HNB, FS, 16)
axis([x1 x2 a b])
grid on
hold on
for j=(nb+1):nf
   x = eval(f);
   plot(x,L,'.c', MS, 2)
end
hold off
zoom on
fprintf('\n Zoom is on in the figure. \n')
fprintf('\n')
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright Massachusetts Institute of Technology
% Version 01 by Rodolfo R. Rosales  10-12-1999.
% Version 02 by Rodolfo R. Rosales  09-27-2004.
% 
% Permission is hereby granted, without payment, to copy this software
% and its documentation, if any,  for non-profit academic and research
% purposes,  provided that the above copyright notice, this paragraph,
% and the following three paragraphs appear in all copies of this
% software. Use of this software constitutes acceptance of these terms
% and conditions.
%
% IN NO EVENT SHALL MIT, OR THE AUTHOR, BE LIABLE TO ANY PARTY FOR
% DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
% ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN
% IF MIT, OR THE AUTHOR, HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH
% DAMAGE.
%
% MIT, AND THE AUTHOR, SPECIFICALLY DISCLAIM ANY EXPRESS OR IMPLIED
% WARRANTIES INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
% NON-INFRINGEMENT.
%
% THIS SOFTWARE IS PROVIDED "AS IS." MIT, OR THE AUTHOR, HAVE NO
% OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS,
% OR MODIFICATIONS.
%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% EOF
