function PHPL23plt(FunFcn, t0, tfinal, y0, tol, Nplt)
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function PHPL23plt(FunFcn, t0, tfinal, y0, tol, Nplt)
% _______________________________________________________________________________
% 18.385 (Nonlinear Dynamical Systems).            MIT, Fall 1999. R. R. Rosales.
%
% MY COMMENTS:
% This is an adaptation (for 2D plots; i.e.: PHPL... = PHase PLane) of the script
% ode23p that existed in the MatLab versions 4.x --- specifically, I took it from
% MatLab version 4.2c.b for the Mac. There are however, many modifications that I
% introduced while using the code.
%
% In MatLab 5.x:    ode23p was replaced by the powerful set of options allowed by
%                   ode23.        But this new and more powerful approach is more
% complicated to use and the dynamical plotting ends up not looking as nice!   At
% least I have not been able to get it right ........ apparently, neither can the
% MatLab guys: for example, in the Lorenz demo they do not use this new approach;
% in fact they have buried inside the code a copy of the relevant parts of ode23p
% to get the desired behavior! Frankly, I don't get it: why was ode23p suppressed
% in MatLab 5, given that even their own programers seem to find the old code (at
% least sometimes) useful! A real mystery were we the users are the loosers.
%
% WARNING: because this runs in script form only (there is no mex file),   it may
%          not be too fast ..... then again, neither did ode23p use a mex file in
%          MatLab 4 and it performed OK there.
% NOTE: I did several modifications to the ode23p script, as follows:
%       1) Split code into separate 2D (PHPL23plt) and 3D (PS3D23plt) versions.
%          See PS3D23plt for info about the 3D version.
%       2) Changes: so the script would work properly both in versions 4 and 5 of
%          MatLab. Changes in the way line and marker properties are handled from
%          MatLab 4 to 5 forced this. In the process I ended up introducing a few
%          "improvements" on the way the pictures produced look.
%       3) Changes to avoid fragmentation errors, due to "macho" coding short-cut
%          features that work in MatLab 4.x, but screw up in 5.x (sometimes).
% _______________________________________________________________________________
%
% FROM THE ode23p HELP HEADER (modified by me):
%
% Solve differential equations, low order method, displaying plot.    Integrate a
% system of ODE's,   using 2nd and 3rd order Runge-Kutta formulas,   and plot the
% time evolution of the first two components of the solution (the system of ode's
% can have ANY NUMBER >= 2 OF COMPONENTS).
%                        
% PHPL23plt('FUN', t0, tfinal, y0, tol) generates a two dimensional (phase plane)
% plot of the solution to the system of ode's described by the M-file FUN.M, over
% the interval [t0, tfinal], using initial conditions y0.
%
% Before calling PHPL23plt, establish the appropriate axis limits with
%
% axis([y1min y1max y2min y2max]);
% hold on
%
% Then call PHPL23plt('FUN', t0, tfinal, y0, tol, Nplt) where
%
% FUN ..... Name of the function defining the differential equation.
%           yprime = fun(t,y) where
%           t      - Time (scalar).
%           y      - Solution COLUMN-vector.
%           yprime - Derivative COLUMN-vector; yprime(i) = dy(i)/dt.
% t0 ...... Initial value of t.
% tfinal .. Final value of t.
% y0 ...... Initial value COLUMN-vector, of length >= 2.
% tol ..... The desired accuracy.
%           This last argument is optional, with a default: tol = 1.e-3.
%           WARNING: the default tolerance is not too high; thus the solution may
%                    not be too trustworthy with it.   Best to check it by taking
%           various tolerances and finding a good choice ("further reduction does
%           not change the answer" is a reasonable criteria).
% Nplt .... Length 2 array with the indexes of the coordinates to be plotted.  An
%           optional argument, with default Nplt = [1, 2].
%
% WARNING on OPTIONAL arguments: both tol and Nplt can be skipped,  or only Nplt,
%           but one cannot skip tol and attempt to use Nplt!
% _______________________________________________________________________________
% NOTE:  MORE INPUT/OUTPUT parameters can be accessed via global variables listed
%        at the very beginning of the script.
% _______________________________________________________________________________
% ode23p copyright notice said:
% C.B. Moler, 3-25-87, 10-5-91, 6-3-93, 11-22-93.
% Copyright (c) 1984-94 by The MathWorks, Inc.
%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% More input/outputs via global variables. ______________________________________
% ALL these global variables correspond to internal variables with names equal to
% the global ones, with the glob_ part removed.    The script DOES NOT change the
% value of any of the INPUT global variables.  The internal input values take the
% values of the global variables when they are assigned, else they take a default
% value  (thus the script will work even if none of these variables is defined in
% the environment external to the script).
%
global glob_chead glob_cbody glob_ctail
   % --- These are INPUTS                         (Why names: the c is for color)
   %     and can be used to change the colors for the head, body and tail.
   %     DEFAULTS: chead = 'r', cbody = 'y' and ctail = 'b'.
   %
global glob_SzH glob_SzB glob_SzT
   % --- These are INPUTS                    (Why names: Sz = Size; H=head, etc.)
   %     and can be used to change the sizes for the head, body and tail.
   %     DEFAULTS: SzH = 25 and SzB = SzT = 0.5.
   %
global glob_Tor glob_Yor glob_STR glob_PeP glob_NCA
   % --- The first two are OUTPUTS:       (Why names: T = time, or = orbit, etc.)
   %     glob_Tor = Row array with the times computed. ................ NOTE (*).
   %     glob_Yor = Array with the solution; each column
   %                   corresponts to a time in glob_Tor. ............. NOTE (*).
   %
   % --- The others are INPUTS:      (Why names: STR = store, PeP= Permanent Plot
   %                                             NCA = No cla)
   %     glob_STR...NOTE (*): glob_Tor and glob_Yor are as above ONLY
   %                ^^^^^^^^  IF STR=1. ELSE they are empty!!
   %                DEFAULT: STR = 0 (except, see when PeP=1 below).
   %     glob_PeP...If PeP = 1, the script redraws the orbit at the end,
   %                   so it is "Permanent" (this produces a FIGURE that
   %                   can be SAVED); else this is not possible (#1)!   
   %                DEFAULT: PeP = 0.
   %                WARNING: Setting PeP=1 will ALSO set STR=1
   %                         (Tor & Yor are needed to redraw the orbit).
   %     glob_NCA...If NCA = 1, the script will not do a "cla" before it
   %                   draws the orbit (#2).
   %                DEFAULT: NCA = 0.
   % (#1) In order to draw the orbit dynamically,  as it is computed,  one cannot
   %      set the "EraseMode" properties of the lines used to "normal"  (else the
   %      picture "flickers" each time a new piece of the orbit is added).   This
   %      has the (unfortunate) consequence of making the plotted lines "fragile"
   %      (it's very easy to loose them); in particular: saving the figure cannot
   %      be done. THIS IS AS FAR AS I CAN UNDERSTAND WHAT IS GOING ON HERE.
   % (#2) Before defining the head, body and tail for the plotting "comet",   the
   %      script (normally) does a "cla" that deletes all non-hidden objects from
   %      the current axes. This is mostly desired  (else one may end up plotting
   %      the orbit on a cluttered figure), but sometimes it is NOT desired!  For
   %      example if one wants to keep these objects on the figure!
   %
   %      BY THE WAY: notice that if many orbits are being drawn on the same
   %                  figure by the script set on "non-permanent" mode (i.e.
   %      the default PeP = 0) the orbits will not be wiped by the "cla" and
   %      in this case setting NCA = 1 is not needed.  It is only when PeP=1
   %      and the orbits are "permanent" that setting NCA=1 becomes crucial!
   %
global glo_dir
   % --- INPUT variable                               (Why name: dir = direction)
   %     When dir =  1 the script assumes it is plotting forwards  in time.
   %     """""""""" -1 """"""""""""""""""""""""""""""""" backwards """"""""
   %     DEFAULT: dir = 1.
   %     NOTE this one is NOT CALLED glob_dir for historical reasons.
   %
global glob_YAR glob_FAR glob_carrow
   % --- INPUT VARIABLES        (Why names: YAR = yes arrow FAR = Fraction arrow)
   %     YAR = 1 causes a small arrow to be drawn at the start of the orbit.
   %     YAR = 2 """""""""""""""""""""""""""""""" halfway on the orbit.
   %     YAR = 3 """""""""""""""""""""""""""""""" at the end of the orbit. 
   %     But: ONLY IF PeP = 1. The value of dir DETERMINES THE ARROW DIRECTION.
   %        DEFAULT: YAR = 2.
   %     FAR determines the length of the arrow, which is: (diagonal figure)/FAR.
   %        DEFAULT: FAR = 25.
   %     carrow is the color of the arrow. DEFAULT is carrow = chead.
   %
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% REAL CODE BEGINS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Set the values for variables that may be inputs via global variables. _________
%
% --- Colors for head, body and tail:
if isempty(glob_chead); chead = 'r'; else; chead = glob_chead; end
if isempty(glob_cbody); cbody = 'y'; else; cbody = glob_cbody; end
if isempty(glob_ctail); ctail = 'b'; else; ctail = glob_ctail; end
% --- Sizes for head, body and tail:
if isempty(glob_SzH); SzH = 25.0; else; SzH = glob_SzH; end
if isempty(glob_SzB); SzB =  0.5; else; SzB = glob_SzB; end
if isempty(glob_SzT); SzT =  0.5; else; SzT = glob_SzT; end
% --- Store/Not store solution:
if isempty(glob_STR); STR = 0; else; STR = glob_STR; end
% --- Plot: Permanent/Non-permanent:
if isempty(glob_PeP); PeP = 0; else; PeP = glob_PeP; end
if PeP == 1; STR = 1; end
% --- Clear/Not Clear axes before drawing:
if isempty(glob_NCA); NCA = 0; else; NCA = glob_NCA; end
% --- Direction in time:
if isempty(glo_dir); dir = 1; else; dir = glo_dir; end
% --- Arrow in plot:
if isempty(glob_YAR);       YAR =  2;    else;    YAR = glob_YAR;    end
if isempty(glob_FAR);       FAR = 25;    else;    FAR = glob_FAR;    end
if isempty(glob_carrow); carrow = chead; else; carrow = glob_carrow; end
%
% Default components to be plotted: _____________________________________________
%
n1 = 1; n2 = 2;
%
% Figure version number: ________________________________________________________
% This is needed below when defining the "head" in the plotting comet.
%
Mat_ver = version;
Mat_ver = str2num(Mat_ver(1));
if Mat_ver <= 4
   DOTS = 'LineStyle';
else
   DOTS = 'Marker';
end
%
if (Mat_ver < 4) | (Mat_ver > 5)
   fprintf('\n NOTE: the script PHPL23plt may not work properly') 
   fprintf('\n       for MatLab versions other than 4.x or 5.x. \n')
end
%
% Initialization ________________________________________________________________
%
pow = 1/3;
if nargin < 5
   tol = 0.001;
   fprintf('\n Using default tolerance tol = 0.001. \n'); 
end
hmax = (tfinal - t0)/16;
hmin = (tfinal - t0)/200000;
h = hmax/8;
tau = tol * max(norm(y0, 'inf'), 1.0);
t = t0;
y = y0;
if STR == 1 % --- Store results of calculation iff STR = 1.
   Tor = t0;%     Tor = Array of times.
   Yor = y0;%     Yor = Array of values on orbit (each column is a time).
end
%
% Error checks __________________________________________________________________
%
if hmax <= 0
   error('WARNING: tfinal must be larger than t0.')
end
%
[p, q] = size(y0);
%
if (p < 2) | (q > 1)
   error('WARNING: y0 must be a COLUMN array of length > 1')
end
%
if nargin == 6
   n1 = floor(Nplt(1) + 0.01); n2 = floor(Nplt(2) + 0.01);
end
%
% Save L steps and plot like a comet tail. ______________________________________
%
L = 50;
Y = y*ones(1,L);
if NCA~=1 % --- Clear axes unless NCA = 1.
   cla
end
%
head = line( ...
      'color',       chead, ...
       DOTS,           '.', ...
      'MarkerSize',    SzH, ...
      'EraseMode',   'xor', ...
      'xdata',       y(n1), ...
      'ydata',       y(n2));
%
body = line( ...
      'color',      cbody, ...
      'LineStyle',    '-', ...
      'LineWidth',    SzB, ...
      'EraseMode', 'none', ...
      'xdata',      y(n1), ...
      'ydata',      y(n2));
%
% --- The Original had in the last line, the line below instead. This line causes
%     segmentation faults in the 3D MatLab 5 version of this code,  PS3D23plt ---
%     at least,  in the Student Version.     I am not sure what is the reason for
%     this ... but the fix works.   Sounds also less dangerous than the original,
%     that gave empty data (possible source of confusion, I guess).
%
%     'xdata', [], 'ydata', []);
%
tail = line( ...
      'color',      ctail, ...
      'LineStyle',    '-', ...
      'LineWidth',    SzT, ...
      'EraseMode', 'none', ...
      'xdata',      y(n1), ...
      'ydata',      y(n2));
%
% --- Same comment as above regarding segmentation faults.
%
%      'xdata', [], 'ydata', []);
%
% The main loop _________________________________________________________________
%
while (t < tfinal) & (h >= hmin)
   if t + h > tfinal
      h = tfinal - t;
   end
%  %
%  % Compute the slopes ................................................
%  %
   s1 = feval(FunFcn, t, y);
   s2 = feval(FunFcn, t+h, y+h*s1);
   s3 = feval(FunFcn, t+h/2, y+h*(s1+s2)/4);
%  %
%  % Estimate the error and the acceptable error .......................
%  %
   delta = norm(h*(s1 - 2*s3 + s2)/3, 'inf');
   tau = tol * max(norm(y, 'inf'), 1.0);
%  %
%  % Update the solution only if the error is acceptable ...............
%  %
   if delta <= tau
      t = t + h;
      y = y + h*(s1 + 4*s3 + s2)/6;
      if STR == 1% --- Store results of calculation iff STR = 1.
         Tor = [Tor, t];
         Yor = [Yor, y];
      end
%     %
%     % Update the plot .......................................
%     %
      Y = [y Y(:,1:L-1)];
      set(head, 'xdata', Y(n1,1), ...
                'ydata', Y(n2,1))
      set(body, 'xdata', Y(n1,1:2), ...
                'ydata', Y(n2,1:2))
      set(tail, 'xdata', Y(n1,L-1:L), ...
                'ydata', Y(n2,L-1:L))
      drawnow;
   end
%  %
%  % Update the step size ..............................................
%  %
   if delta ~= 0.0
      h = min(hmax, 0.9*h*(tau/delta)^pow);
   end
end
%
% Error message when target time tfinal not reached _____________________________
% This would happen because h < hmin at some point.
%
if (t < tfinal)
   TEXTt = num2str(t);
   fprintf('\n')
   disp(['Could not reach target time. Stopped at t = ', TEXTt])
   disp('Singularity likely.')
   fprintf('\n')
end
%
% Redraw orbit to get "permanent" plot that saves properly ______________________
% and put "double" arrow on the orbit (if appropriate).
%
if PeP == 1 % --- Redraw orbit if PeP = 1
   delete(head); delete(body); delete(tail);
   plot(Yor(n1,:), Yor(n2,:), '-', 'color', ctail, 'LineWidth', SzT)
   % --- Put an arrow on the orbit.
   nT = length(Tor);
   if ((YAR == 1) | (YAR == 2) | (YAR == 3)) & (nT > 1)
      Ax = axis;% Gives the current axis; compute (next) Arrow Length:
      Al = dir*(sqrt((Ax(2)-Ax(1))^2 + (Ax(4)-Ax(3))^2))/FAR;
      if YAR == 1
         P0 = Yor([n1, n2], 1);
         P1 = Yor([n1, n2], 2);
      elseif YAR == 2
         P0 = Yor([n1, n2], floor(0.5*nT+0.01));
         P1 = Yor([n1, n2],  ceil(0.5*nT+0.01));
      elseif YAR == 3
         P0 = Yor([n1, n2], nT-1);
         P1 = Yor([n1, n2], nT);
      end
      if norm(P1-P0) > 0
         uda = (P1-P0)/norm(P1-P0);%Unit vector in the Direction of the Arrow.
         P1  = P0 + Al*uda;
         dP2 = [uda(2); -uda(1)];
         P2p = P0 + (Al/3)*dP2/norm(dP2); P2m = P0 - (Al/3)*dP2/norm(dP2);
         P = [P1, P2p, P2m];
         fill(P(1, :), P(2, :), carrow);
      end
   end
end
%
% --- If the orbit was stored, pass it along. ___________________________________
%
if STR == 1
   glob_Tor = Tor;
   glob_Yor = Yor;
end
%
%% End of File %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
