function PHPLdemoA(t_f, tol, BF)
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PHPLdemoA(t_f, tol, BF)
% ____________________________________________________________________________
% 18.385 (Nonlinear Dynamical Systems).    MIT, Fall 1999-2004. R. R. Rosales.
%
% This demo illustrates the Phase Plane behavior of the nonlinear oscillator:
%
%                du/dt = f(u,v)    and   dv/dt = g(u,v),
%
% where f & g are given by the various options in PHPLfunct  (includes users f
% and g as a possible).  Orbits are computed and plotted starting with a mouse
% selected initial point.    Plotting is done (forwards and backwards in time,
% using PHPL23plt) dynamically, as the computation proceeds.
%
% Similar to PHPLdemoB, but gives rougher looking and less accurate plots.
% See ........ PHPLreadme.
%
% INPUTS are OPTIONAL: use either all, first two, first or none:
% -- t_f ... Solution computed for 0 <= t <= t_f (& -t_f <= t <= 0 if BF = 1).
%            DEFAULT is t_f = 20.
% -- tol ... Tolerance used by PHPL23plt. DEFAULT is tol = 1e-5.
% -- BF .... If BF = 1,  the solution is computed forwards & backwards in time
%            from the mouse selected point.   If BF = 0,  calculation proceeds
%            forwards only. DEFAULT is BF = 1.
%
% Copyright at the end of this script file.
%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% ***************************** Figure out MatLab version number. **********
%
Mat_ver = version;
Mat_ver =str2num(Mat_ver(1));
if (Mat_ver < 4) | (Mat_ver > 5)
   fprintf('\n ')
   disp([' WARNING: this script may not work properly with '; ...
         '          MatLab versions other than 4 or 5.     ']);
end
%
% ***************************** Integration times and error tolerances. ****
%
if nargin == 0
   t_f = 20; tol = 1e-5; BF = 1;
elseif nargin == 1
   tol = 1e-5; BF = 1;
elseif nargin == 2
   BF = 1;
end
t_0 = 0;
%
% ************************************** Global Variables ******************
% glo_option ................. selects example.
% TEXTT ...................... title of figure.
% [umin, umax, vmin, vmax] ... figure bounds.
% Rmax2 ...................... switch radius squared:  turn-off nonlinearity
%                              to avoid finite time blow-up in solution.
% glo_dir .................... determines direction of time integration.
% TEXTF, TEXTG ............... string variables with user functions f and g.
% glob_mu ..................... parameter in equation.
%
global glo_option TEXTT umin umax vmin vmax Rmax2 glo_dir TEXF TEXG glob_mu
%
% give default values to global variables.  Needed to avoid trouble when the
% user skips a choice or when "fake" calls to PHPLfunct are made (see code).
%
glo_option = 1;
glo_dir = 1;
umin = -1; umax = 1; vmin = -1; vmax = 1; Rmax2 = 3;
ejes = [umin umax vmin vmax];
TEXTF = 'v'; TEXTG = '-u';
TEXTT = ['du/dt = ', TEXF, ' and dv/dt = ', TEXG];
glob_mu = 0;
%
% --- More global variables. These ones for fine control of PHPL23plt
%
global glob_chead glob_cbody glob_ctail
glob_chead = 'r';% Head color. Default is red.
glob_cbody = 'y';% Body color. Default is yellow.
glob_ctail = 'b';% Tail color. Default is blue.
global glob_SzH glob_SzB glob_SzT
glob_SzH = 25;   % Size of head.  Default is 25.
glob_SzB =  2.00;% Width of body. Default is 0.5.
glob_SzT =  2.00;% """""""" tail. """"""""""""""
global glob_Tor glob_Yor glob_STR glob_PeP glob_NCA
%            % Will not use neither glob_Tor nor glob_Yor.
glob_STR = 1;% Store the orbit if equal to 1. Default is 0 (don't store).
glob_PeP = 1;% Draw savable figure if equal to 1. Default is 0.
glob_NCA = 1;% Do not clear axis if equal to 1. Default is 0.
global glob_YAR glob_FAR glob_carrow
glob_YAR    =   1;% Draw arrow at beginning of orbit going forward in time.
                  % Default is 2 (draw halfway in orbit).
glob_FAR    =  30;% Size of arrow = diagonal/FAR. Default is 25.
glob_carrow = 'r';% Color of arrow. Default is equal to head color.
%
% +++++++++++++++++ Abreviations for titles, parameters, etc. ++++++++++++++
%
FN  = 'FontName';
HNB = 'HelveticaNarrowBold';
FS  = 'FontSize';
FU  = 'FontUnits';
FW  = 'FontWeight';
LW  = 'LineWidth';
COL = ['y'; 'm'; 'c'; 'r'; 'g'; 'b'];
    % --- COL contains colors to use in the plots.
nf  = 0;
    % --- Contains number of figures at each stage of the code.
Fn  = [];
    % --- Array with the figure handles.
ScS = get(0, 'ScreenSize');
ScW = ScS(3);% ---------- Screen Width.
ScH = ScS(4);% ---------- Screen Height.
SMD = min(ScW, ScH);% --- Screen Minimum Dimension.
IfP = [0.02*ScW, ScH-0.12*ScH, 0.06*ScW, 0.06*ScH];
    % --- First figure Icon Position.
%
% ++++ Now code starts. ++++++++++++++++++++++++++++++++++++++++++++++++++++
% GO_ON is used to repeat and go back to a new choice.
%
GO_ON = 1;
while GO_ON == 1 % The end for this while is at the very end of script. <<<<
%                  ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
% Introduce now code and options:
%
PHPLnotes
%
glo_option = input('       Enter option now. OPTION = ');
   if isempty(glo_option); glo_option = 1; end
%
if glo_option == 0
   help PHPLnotes
   TEXF  = input('  1st function f = ');
      if isempty(TEXF); TEXF =  'v'; end
   TEXG  = input('  2nd function g = ');
      if isempty(TEXG); TEXG = '-u'; end
   ejes  = input('   axis for plot = ');
      if isempty(ejes); ejes = [-1 1 -1 1]; end
   umin = ejes(1); umax = ejes(2); vmin = ejes(3); vmax = ejes(4);
      if (umin >= umax) | (vmin >= vmax)
         ejes = [-1 1 -1 1]; umin=-1; umax=1; vmin=-1; vmax=1;
      end
   TEXTT = ['du/dt = ', TEXF, ' and dv/dt = ', TEXG];
elseif glo_option == 12
   glob_mu = input(' Enter value 0 <= mu <= 10 in the equation. mu = ');
      if isempty(glob_mu); glob_mu = 0; end
end
%
fprintf('\n CLICK ON THE FIGURE WITH THE MOUSE TO START. Can do so as many')
fprintf('\n times as wanted. Solves FIRST FORWARD in time, NEXT BACKWARDS.')
fprintf('\n TO STOP or CHANGE EQUATIONS, click on the indicated spots.\n')
%
% Now we do a call to PHPLfunct just so that TEXTT, etc. get assigned,  when 
% the user choice is NOT glo_option = 0.  This requires defining a fake y_0.
%
y_0 = [0; 0];
y_0 = PHPLfunct(0, y_0);
Rmax2 = 2*(max(umin^2, umax^2) + max(vmin^2, vmax^2));
%
% Now we assign a fake y_0 to start (need y_0(2) > vmin).  No integration
% occurs till user picks y_0 via the mouse anyway (this is just so we can
% use the same for loop for everything.
% We also setup the figure to do the plotting.
%
y_0 = [0; vmin + 1];
FLAG = -1;
   % --- Figure set up here =============================================
   %     The old figure is "iconified"  (to the left)  and it's xlabel is
   %     "fixed" (i.e.:  get rid of the STO/NEW EQN stuff and plug in the
   %     true label "u(t)".)
   %     We are careful to create a new figure of "large size", with good
   %     nice and proportional axis.
   %
   % --- Iconify old figure (if any).
   if nf > 0 
      set(Fn(nf), 'Position', IfP - (nf-1)*ScH*[0, 0.1, 0, 0])
      xlabel('u(t)', FN, HNB, FS, 18)
   end
   % --- Figure parameters. 
      rati = (umax-umin)/(vmax-vmin);% Plotting area width/height.    
      Mlef = 0.12;% Percent of width  for margin: left.
      Mrig = 0.03;% """"""""""""""""""""""""""""  right.
      Mtop = 0.10;% """""""""" height """"""""""  top.
      Mbot = 0.13;% """"""""""""""""""""""""""""  bottom.
   % --- Figure position.
      FigWidth= rati/(1-Mlef-Mrig);% Provisional figure width.
      FigHeigh=    1/(1-Mtop-Mbot);% """""""""""""""""" height.
      FigMaxWH= max(FigWidth, FigHeigh);
      FigWidth= 0.8*SMD*FigWidth/FigMaxWH;% Final figure width.
      FigHeigh= 0.8*SMD*FigHeigh/FigMaxWH;% """""""""""" height.
      FigPosit= [0.97*ScW-FigWidth,0.97*ScH-FigHeigh,FigWidth,FigHeigh];
   % --- Figure plot area.
      PlotArea = [Mlef, Mbot, 1-Mlef-Mrig, 1-Mbot-Mtop];
   % --- Create figure and axes. Set desired properties.
      ff = figure;
      set(ff, 'Position', FigPosit)
      hf = axes('Units', 'normalized', 'Position',  PlotArea);
      if Mat_ver < 5
         set(hf, FW, 'demi', LW, 2, FS, 14)
      elseif Mat_ver > 4
         set(hf, FU, 'points', FW, 'demi', LW, 2, FS, 14)
      end        
   % --- Color, hold, grid and axis limits.
      whitebg('k')
      hold on
      grid on
      axis([umin umax vmin vmax])
   % --- Make tittle and position it correctly.
      if Mat_ver < 5
         title(TEXTT, FN, HNB, FS, 16)
      elseif Mat_ver > 4
         ttHndl = title(TEXTT, FN, HNB, FS, 16, 'Color', 'w');
         ttPos  = get(ttHndl, 'Position');
         set(ttHndl, 'Position', ttPos + [0, 1.0*(ttPos(2)-vmax), 0])
      end
   % --- Make xlabel and position it correctly.
      TEXTxl = 'TO STOP   <<==== click ====>>   NEW EQN';
      if Mat_ver < 5
         xlabel(TEXTxl, FN, HNB, FS, 18); 
      elseif Mat_ver > 4
         xlHndl = xlabel(TEXTxl, FN, HNB, FS, 18);
         xlPos  = get(xlHndl, 'Position');
         set(xlHndl, 'Position', xlPos - [0, 0.3*(vmin-xlPos(2)), 0])
      end
   % --- Make y label and position it correctly.
      if Mat_ver < 5
         ylabel('v(t)', FN, HNB, FS, 18);
      elseif Mat_ver > 4
         ylHndl = ylabel('v(t)', FN, HNB, FS, 18);
         ylPos  = get(ylHndl, 'Position');
         set(ylHndl, 'Position', ylPos - [0.2*(umin-ylPos(1)), 0, 0])
      end
   % --- Update figure number and store figure handle.
      nf = nf+1;
      Fn = [Fn, ff];  
   %
   % --- End of figure set up ===========================================
%
np = 0;% Contains number of orbits plotted.
while y_0(2) > vmin
      if FLAG > 0
         np = np+1;
            % --- Cycle colors for orbits:
            n_cbody = np-6*floor((np-0.5)/6);
            n_chead = np+1-6*floor((np+0.5)/6);
            n_ctail = np+2-6*floor((np+1.5)/6);
            glob_chead  = COL(n_chead, :);
            glob_cbody  = COL(n_cbody, :);
            glob_ctail  = COL(n_ctail, :);
         glob_carrow = glob_ctail;
         glo_dir = 1;
         glob_YAR = 1;
         if BF ~= 1
            glob_YAR = 0;
         end
         PHPL23plt('PHPLfunct', t_0, t_f, y_0, tol);
         if BF == 1
            glo_dir = -1;
            glob_YAR = 0;
            PHPL23plt('PHPLfunct', t_0, t_f, y_0, tol);
         end
      end
      FLAG = 1;
      y_0 = ginput(1); y_0 = y_0';
end
%
if y_0(1) < (0.4*umin+0.6*umax)
   GO_ON = 0;
end
%
end %+++++++++++++ END OF THE while GO_ON == 1 <<<<<<<<<<<<<<<<<<<<<<<<<<<<<
%                  ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
xlabel('u(t)', FN, HNB, FS, 18)
   % --- get rid of the choices on the x-label place in last figure.

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright Massachusetts Institute of Technology
% Version 01 by Rodolfo R. Rosales  10-24-1999.
% Version 02 by Rodolfo R. Rosales  10-17-2004.
% 
% Permission is hereby granted, without payment, to copy this software
% and its documentation, if any,  for non-profit academic and research
% purposes,  provided that the above copyright notice, this paragraph,
% and the following three paragraphs appear in all copies of this
% software. Use of this software constitutes acceptance of these terms
% and conditions.
%
% IN NO EVENT SHALL MIT, OR THE AUTHOR, BE LIABLE TO ANY PARTY FOR
% DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
% ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN
% IF MIT, OR THE AUTHOR, HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH
% DAMAGE.
%
% MIT, AND THE AUTHOR, SPECIFICALLY DISCLAIM ANY EXPRESS OR IMPLIED
% WARRANTIES INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
% NON-INFRINGEMENT.
%
% THIS SOFTWARE IS PROVIDED "AS IS." MIT, OR THE AUTHOR, HAVE NO
% OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS,
% OR MODIFICATIONS.
%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% EOF
