function   f = SetUpFig(Name, fW, fH, dX, dY, aW, aH, OvTitl, FontSz)
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function f = SetUpFig(Name, fW, fH, dX, dY, aW, aH, OvTitl, FontSz)
%
% 18.385 (Nonlinear Dynamical Systems). MIT, Fall 2000-2005. R. R. Rosales.
% _________________________________________________________________________
% Set-up a Figure Window on the screen. Makes axis fonts "nice".
% Lengths are measured as fractions of the screen minimum length.
%
% f ........... Figure handle.
% Name ........ Figure name on menu bar.
% fW .......... Figure window width.
% fH .......... """"""""""""" height.
% dX .......... Distance of the figure window from the right edge of screen.
% dY .......... """""""""""""""""""""""""""""""""""""" top   """""""""""""""
% aW .......... Plotting area width,  in fractions of fW.
% aH .......... """"""""""""" height, """"""""""""""" fH.
% OvTitl ...... Over Title (goes over the axis title.) \ OPTIONAL.
% FontSz ...... Font size used in OverTitle.           / Neither or both!
%               ^^^^^^^^^ Given in FRACTIONS OF fW.
% WHEN USING OvTitl, SET HOLD ON BEFORE PLOTTING.
%
% Copyright at the end of this script file.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% --- Get screen data and calculate:
%     SW = Screen Width
%     SH = Screen Height
%     Sml = Screen minimum length.
SSz = get(0, 'ScreenSize');  SW = SSz(3);  SH = SSz(4);  Sml = min(SW, SH);
% --- Calculate now figure position.
POS = [0.97*SW - (fW + dX)*Sml, 0.94*SH - (fH + dY)*Sml, fW*Sml, fH*Sml];
% --- Setup figure.
f = figure('Visible', 'off');
set(f, 'Name',        [' ', Name, ' '], ...
       'NumberTitle', 'off', ...
       'Position',    POS)
whitebg(f, 'k')
%
% --- Setup axes.
%     FS = space reserved for the over-title.
%     Left and right margins are biased by a 6 to 4 ratio.
%     Top and bottom margins, after the space FS, are equal.
%
FS = 0;  if nargin > 7;  FS = 1.2*FontSz;  end
POS = [0.6*(1-aW), 0.5*(1-aH-FS), aW, aH];
set(gca, 'FontUnits',  'points', ...
         'FontWeight', 'demi', ...
         'FontSize',    16, ...
         'LineWidth',   2, ...
         'Position',    POS, ...
         'Box',         'on')
% --- Setup overtitle.
%     Conversion from fractions of fW to axis normalized units: divide by aH.
%     Note that POS(2) is the vertical axis margin.
%     Also: text is centered on the height of the second coordinate. 
if nargin > 7
   text(0.46, 1 + (POS(2) + 0.5*FontSz)/aH, ['{\bf ', OvTitl, '}'], ...
         'FontUnits',           'Normalized', ...
         'Units',               'Normalized', ...
         'HorizontalAlignment', 'center', ...
         'FontSize',            FontSz/aH)

end
set(f, 'Visible', 'on')
if nargout == 0;   clear f;   end
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright Massachusetts Institute of Technology
% Version 01 by Rodolfo R. Rosales  10-01-2000.
% Version 02 by Rodolfo R. Rosales  11-02-2005.
% 
% Permission is hereby granted, without payment, to copy this software
% and its documentation, if any,  for non-profit academic and research
% purposes,  provided that the above copyright notice, this paragraph,
% and the following three paragraphs appear in all copies of this
% software. Use of this software constitutes acceptance of these terms
% and conditions.
%
% IN NO EVENT SHALL MIT, OR THE AUTHOR, BE LIABLE TO ANY PARTY FOR
% DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
% ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN
% IF MIT, OR THE AUTHOR, HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH
% DAMAGE.
%
% MIT, AND THE AUTHOR, SPECIFICALLY DISCLAIM ANY EXPRESS OR IMPLIED
% WARRANTIES INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
% NON-INFRINGEMENT.
%
% THIS SOFTWARE IS PROVIDED "AS IS." MIT, OR THE AUTHOR, HAVE NO
% OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS,
% OR MODIFICATIONS.
%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% EOF
