function flag = existFIG(Fhandle)
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function flag = existFIG(Fhandle)
% ____________________________________________________________________________
% 18.385 (Nonlinear Dynamical Systems).    MIT, Fall 1999-2005. R. R. Rosales.
%
% flag = 1 if figure with handle Fhandle is     currently displayed on screen.
% flag = 0 if """"""""""""""""""""""""""""" NOT """""""""""""""""""""""""""""
%
% If the input is an array of handles, the output will have the same shape.
%
% If no input is given, then flag will be a column array, with all the figure
% handles for figures currently open.
%
% This script is similar to figflag,  but checks for the figure handle instead
% of the figure name.
%
% Copyright at the end of this script file.
%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% ____________________________________________________________________________
% Figure out MatLab version number. __________________________________________
%
Mat_ver = version;
Mat_ver = str2num(Mat_ver(1));
if (Mat_ver < 4) | (Mat_ver > 5)
   fprintf('\n ')
   disp([' WARNING: this script may not work properly with '; ...
         '          MatLab versions other than 4 or 5.     ']); 
end
% ____________________________________________________________________________
% Error checks. ______________________________________________________________
%
if nargin == 0,
   flag = [];
elseif ~isreal(Fhandle)
   flag = 0;
   return
elseif isempty(Fhandle)
   flag = 0;
   return
else
   flag = Fhandle;
end
%
% ____________________________________________________________________________
% Do it now. _________________________________________________________________
%
fighdl = [];
hdlchi = get(0, 'Children');
for n = 1:length(hdlchi)
   if strcmp(get(hdlchi(n), 'type'), 'figure')
      fighdl = [fighdl; hdlchi(n)];
   end
end
fighdl = sort(fighdl);
if nargin == 0
   flag = fighdl;
else
   for n=1:prod(size(Fhandle))
      flag(n) = max(fighdl == Fhandle(n));
   end
end
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright Massachusetts Institute of Technology
% Version 01 by Rodolfo R. Rosales  09-14-1999.
% Version 02 by Rodolfo R. Rosales  10-28-2005.
% 
% Permission is hereby granted, without payment, to copy this software
% and its documentation, if any,  for non-profit academic and research
% purposes,  provided that the above copyright notice, this paragraph,
% and the following three paragraphs appear in all copies of this
% software. Use of this software constitutes acceptance of these terms
% and conditions.
%
% IN NO EVENT SHALL MIT, OR THE AUTHOR, BE LIABLE TO ANY PARTY FOR
% DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
% ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN
% IF MIT, OR THE AUTHOR, HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH
% DAMAGE.
%
% MIT, AND THE AUTHOR, SPECIFICALLY DISCLAIM ANY EXPRESS OR IMPLIED
% WARRANTIES INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
% NON-INFRINGEMENT.
%
% THIS SOFTWARE IS PROVIDED "AS IS." MIT, OR THE AUTHOR, HAVE NO
% OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS,
% OR MODIFICATIONS.
%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% EOF
